@@ -143,6 +143,7 @@ typedef struct Hookables
 Hookables hook_function_templates[] =
 {
 	{ "ACTION",		NULL,	3,	0,	0,	NULL, 0 },
+	{ "CHANNEL_CLAIM", 	NULL, 	2,  	0,  	0,  	NULL, 0 },
 	{ "CHANNEL_LOST", 	NULL, 	2,  	0,  	0,  	NULL, 0 },
 	{ "CHANNEL_NICK",	NULL,	3,	0,	0,	NULL, 0 },
 	{ "CHANNEL_SIGNOFF",	NULL,	3,	0,	0,	NULL, 0 },
@@ -733,9 +734,7 @@ static int 	do_hook_internal (int which, char **result, const char *format, va_l
 	int		serial_number;
 	struct Current_hook *hook;
 	Hookables *	h;
-	va_list		orig_args;
 
-	va_copy(orig_args, args);
 	*result = NULL;
 
 	if (!hook_functions_initialized)
@@ -750,7 +749,6 @@ static int 	do_hook_internal (int which, char **result, const char *format, va_l
 	if (!format)
 		panic(1, "do_hook: format is NULL (hook type %d)", which);
 
-	va_copy(args, orig_args);
 	malloc_vsprintf(&buffer, format, args);
 
 
