@@ -79,6 +79,8 @@ struct	channel_stru *	prev;		/* pointer to previous channel */
 	int		curr_count;	/* Current channel precedence */
 
 	/* Channel stuff */
+	int		claimable;	/* Currently up for claiming */
+	int		claiming_window; /* What window claims us */
 	int		waiting;	/* Syncing, waiting for names/who */
 	NickList	nicks;		/* alist of nicks on channel */
 	char 		base_modes[54];	/* Just the modes w/o args */
@@ -160,6 +162,8 @@ static Channel *create_channel (const char *name, int server)
 	new_c->server = server;
 	new_c->waiting = 0;
 	new_c->winref = -1;
+	new_c->claimable = 0;
+	new_c->claiming_window = -1;
 	new_c->nicks.max_alloc = new_c->nicks.max = 0;
 	new_c->nicks.list = NULL;
 	if (get_server_stricmp_table(server) == 0)
@@ -241,6 +245,8 @@ static void 	destroy_channel (Channel *chan)
 	new_free(&chan->channel);
 	chan->server = NOSERV;
 	chan->winref = -1;
+	chan->claimable = -1;
+	chan->claiming_window = -1;
 
 	if (chan->nicks.max_alloc)
 		clear_channel(chan);
@@ -260,6 +266,7 @@ void 	add_channel (const char *name, int server)
 {
 	Channel *new_c;
 	int	was_window = -1;
+	int	claim_window = -1;
 
 	if ((new_c = find_channel(name, server)))
 	{
@@ -278,7 +285,15 @@ void 	add_channel (const char *name, int server)
 		was_window = claim_waiting_channel(name, server);
 
 	if (was_window == -1)
-		was_window = get_winref_by_servref(from_server);
+		was_window = get_winref_by_servref(server);
+
+	new_c->claimable = 1;
+	new_c->claiming_window = -1;
+	do_hook(CHANNEL_CLAIM_LIST, "%d %s %d", server, name, was_window);
+	if (new_c->claiming_window != -1)
+		was_window = new_c->claiming_window;
+	new_c->claimable = 0;
+	new_c->claiming_window = -1;
 
 	set_channel_window(name, from_server, was_window, 1);
 	update_all_windows();
@@ -1428,7 +1443,10 @@ void 	set_channel_window (const char *channel, int server, int winref, int as_cu
 		 * of the target window, then don't do anything more.
 		 */
 		if (is_current_now && tmp->winref == winref && as_current)
+		{
+			yell("%d:%s is already current window of %d", server, channel, winref);
 			return;
+		}
 
 		/*
 		 * We need to know the present current channel of the new
@@ -1630,7 +1648,7 @@ void	channel_check_windows (void)
 	{
 		reset = 0;
 
-		if (tmp->winref > 0)
+		if (tmp->winref > 0 || tmp->claimable)
 			continue;
 
 		w = NULL;
@@ -1666,6 +1684,9 @@ void	channel_check_windows (void)
 	for (tmp = channel_list; tmp; 
 		reset ? (tmp = channel_list) : (tmp = tmp->next))
 	{
+		if (tmp->claimable)
+			continue;
+
 		if (tmp->winref <= 0)
 			panic(1, "I thought we just checked for this! [1]");
 
@@ -1685,6 +1706,9 @@ void	channel_check_windows (void)
 	for (tmp = channel_list; tmp; 
 		reset ? (tmp = channel_list) : (tmp = tmp->next))
 	{
+		if (tmp->claimable)
+			continue;
+
 		if (tmp->winref <= 0)
 			panic(1, "I thought we just checked for this! [2]");
 
@@ -1729,3 +1753,34 @@ void	channels_merge_winrefs (int oldref, int newref)
 	}
 }
 
+int	window_claims_channel (int winref, int winserv, const char *channel)
+{
+	Channel *tmp = NULL;
+
+	for (tmp = channel_list; tmp; tmp = tmp->next)
+	{
+		/* 
+		 * If i'm being honest, only one channel can be claimable at a time.
+		 * The checks for server and channel are just a sanity check for now, 
+		 * to avoid referential integrity errors.  It's not like I don't know
+		 * exactly which channel is claimable at this moment: i just want to 
+		 * make sure you are claiming what you think you are claiming.
+		 */
+		if (tmp->claimable)
+		{
+			/* Make sure you think you're claiming the correct channel */
+			if (my_stricmp(tmp->channel, channel))
+				continue;
+
+			/* Make sure you think you're on the correct server */
+			if (tmp->server != winserv)
+				continue;
+
+			/* Hey, I'm satisfied! */
+			tmp->claiming_window = winref;
+			return 0;
+		}
+	}
+	return -1;
+}
+
