@@ -629,7 +629,7 @@ static char *get_bio_mem_string(BIO *mem)
 
 	bytes = BIO_get_mem_data(mem, &p);
 	
-	if (p && bytes >= 0 && bytes < SIZE_MAX)
+	if (p && bytes >= 0 && (unsigned long)bytes < SIZE_MAX)
 	{
 		char *result = new_malloc((size_t)bytes + 1);
 		memcpy(result, p, bytes);
@@ -862,7 +862,7 @@ int	ssl_connected (int vfd)
 }
 
 
-int	is_ssl_enabled (int vfd)
+int	is_fd_ssl_enabled (int vfd)
 {
 	if (find_ssl(vfd))
 		return 1;
@@ -1017,7 +1017,7 @@ const char *get_ssl_cipher (int vfd)
 	return NULL;
 }
 
-int	is_ssl_enabled (int vfd)
+int	is_fd_ssl_enabled (int vfd)
 {
 	return 0;
 }
